<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-stats?lang_cible=pt_br
// ** ne pas modifier le fichier **

return [

	// S
	'stats_description' => 'Estatísticas do SPIP',
	'stats_nom' => 'Estatísticas',
	'stats_slogan' => 'Gerenciamento das estatísticas do SPIP',
];
